# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: public_trips.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12public_trips.proto\x12\x1dorg.couchers.api.public_trips\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\"\x9b\x03\n\nPublicTrip\x12\x0f\n\x07trip_id\x18\x01 \x01(\x03\x12)\n\x04user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x14\n\x0c\x63ommunity_id\x18\x03 \x01(\x03\x12\x11\n\tfrom_date\x18\x04 \x01(\t\x12\x0f\n\x07to_date\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12?\n\x06status\x18\x07 \x01(\x0e\x32/.org.couchers.api.public_trips.PublicTripStatus\x12+\n\x07\x63reated\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x63ommunity_slug\x18\t \x01(\t\x12\x18\n\x10same_gender_only\x18\n \x01(\x08\x12\x19\n\x0coffers_count\x18\x0b \x01(\x05H\x00\x88\x01\x01\x12\x16\n\x0e\x63ommunity_name\x18\x0c \x01(\t\x12\x1e\n\x16viewer_host_request_id\x18\r \x01(\x03\x42\x0f\n\r_offers_count\"~\n\x13\x43reatePublicTripReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tfrom_date\x18\x02 \x01(\t\x12\x0f\n\x07to_date\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x18\n\x10same_gender_only\x18\x05 \x01(\x08\"#\n\x10GetPublicTripReq\x12\x0f\n\x07trip_id\x18\x01 \x01(\x03\"Q\n\x12ListPublicTripsReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"n\n\x12ListPublicTripsRes\x12?\n\x0cpublic_trips\x18\x01 \x03(\x0b\x32).org.couchers.api.public_trips.PublicTrip\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xab\x01\n\x18ListPublicTripsByUserReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x44\n\x0bstatuses_in\x18\x04 \x03(\x0e\x32/.org.couchers.api.public_trips.PublicTripStatus\x12\x11\n\tascending\x18\x05 \x01(\x08\"t\n\x18ListPublicTripsByUserRes\x12?\n\x0cpublic_trips\x18\x01 \x03(\x0b\x32).org.couchers.api.public_trips.PublicTrip\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9d\x02\n\x13UpdatePublicTripReq\x12\x0f\n\x07trip_id\x18\x01 \x01(\x03\x12\x16\n\tfrom_date\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07to_date\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x44\n\x06status\x18\x05 \x01(\x0e\x32/.org.couchers.api.public_trips.PublicTripStatusH\x03\x88\x01\x01\x12\x1d\n\x10same_gender_only\x18\x06 \x01(\x08H\x04\x88\x01\x01\x42\x0c\n\n_from_dateB\n\n\x08_to_dateB\x0e\n\x0c_descriptionB\t\n\x07_statusB\x13\n\x11_same_gender_only*\x80\x01\n\x10PublicTripStatus\x12\"\n\x1ePUBLIC_TRIP_STATUS_UNSPECIFIED\x10\x00\x12)\n%PUBLIC_TRIP_STATUS_SEARCHING_FOR_HOST\x10\x01\x12\x1d\n\x19PUBLIC_TRIP_STATUS_CLOSED\x10\x02\x32\xf5\x04\n\x0bPublicTrips\x12s\n\x10\x43reatePublicTrip\x12\x32.org.couchers.api.public_trips.CreatePublicTripReq\x1a).org.couchers.api.public_trips.PublicTrip\"\x00\x12m\n\rGetPublicTrip\x12/.org.couchers.api.public_trips.GetPublicTripReq\x1a).org.couchers.api.public_trips.PublicTrip\"\x00\x12y\n\x0fListPublicTrips\x12\x31.org.couchers.api.public_trips.ListPublicTripsReq\x1a\x31.org.couchers.api.public_trips.ListPublicTripsRes\"\x00\x12\x8b\x01\n\x15ListPublicTripsByUser\x12\x37.org.couchers.api.public_trips.ListPublicTripsByUserReq\x1a\x37.org.couchers.api.public_trips.ListPublicTripsByUserRes\"\x00\x12s\n\x10UpdatePublicTrip\x12\x32.org.couchers.api.public_trips.UpdatePublicTripReq\x1a).org.couchers.api.public_trips.PublicTrip\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'public_trips_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PUBLICTRIPS']._loaded_options = None
  _globals['_PUBLICTRIPS']._serialized_options = b'\210\265\030\003'
  _globals['_PUBLICTRIPSTATUS']._serialized_start=1471
  _globals['_PUBLICTRIPSTATUS']._serialized_end=1599
  _globals['_PUBLICTRIP']._serialized_start=117
  _globals['_PUBLICTRIP']._serialized_end=528
  _globals['_CREATEPUBLICTRIPREQ']._serialized_start=530
  _globals['_CREATEPUBLICTRIPREQ']._serialized_end=656
  _globals['_GETPUBLICTRIPREQ']._serialized_start=658
  _globals['_GETPUBLICTRIPREQ']._serialized_end=693
  _globals['_LISTPUBLICTRIPSREQ']._serialized_start=695
  _globals['_LISTPUBLICTRIPSREQ']._serialized_end=776
  _globals['_LISTPUBLICTRIPSRES']._serialized_start=778
  _globals['_LISTPUBLICTRIPSRES']._serialized_end=888
  _globals['_LISTPUBLICTRIPSBYUSERREQ']._serialized_start=891
  _globals['_LISTPUBLICTRIPSBYUSERREQ']._serialized_end=1062
  _globals['_LISTPUBLICTRIPSBYUSERRES']._serialized_start=1064
  _globals['_LISTPUBLICTRIPSBYUSERRES']._serialized_end=1180
  _globals['_UPDATEPUBLICTRIPREQ']._serialized_start=1183
  _globals['_UPDATEPUBLICTRIPREQ']._serialized_end=1468
  _globals['_PUBLICTRIPS']._serialized_start=1602
  _globals['_PUBLICTRIPS']._serialized_end=2231
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import bugs_pb2 as bugs__pb2
from .google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class BugsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Version = channel.unary_unary(
                '/org.couchers.bugs.Bugs/Version',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=bugs__pb2.VersionInfo.FromString,
                )
        self.ReportBug = channel.unary_unary(
                '/org.couchers.bugs.Bugs/ReportBug',
                request_serializer=bugs__pb2.ReportBugReq.SerializeToString,
                response_deserializer=bugs__pb2.ReportBugRes.FromString,
                )
        self.Status = channel.unary_unary(
                '/org.couchers.bugs.Bugs/Status',
                request_serializer=bugs__pb2.StatusReq.SerializeToString,
                response_deserializer=bugs__pb2.StatusRes.FromString,
                )
        self.GetDescriptors = channel.unary_unary(
                '/org.couchers.bugs.Bugs/GetDescriptors',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_api_dot_httpbody__pb2.HttpBody.FromString,
                )
        self.GetNativeUpdateManifest = channel.unary_unary(
                '/org.couchers.bugs.Bugs/GetNativeUpdateManifest',
                request_serializer=google_dot_api_dot_httpbody__pb2.HttpBody.SerializeToString,
                response_deserializer=google_dot_api_dot_httpbody__pb2.HttpBody.FromString,
                )
        self.GeolocationSearchInfo = channel.unary_unary(
                '/org.couchers.bugs.Bugs/GeolocationSearchInfo',
                request_serializer=bugs__pb2.GeolocationSearchInfoReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GeolocationClickInfo = channel.unary_unary(
                '/org.couchers.bugs.Bugs/GeolocationClickInfo',
                request_serializer=bugs__pb2.GeolocationClickInfoReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ReportDiagnostics = channel.unary_unary(
                '/org.couchers.bugs.Bugs/ReportDiagnostics',
                request_serializer=bugs__pb2.ReportDiagnosticsReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CheckNativeStatus = channel.unary_unary(
                '/org.couchers.bugs.Bugs/CheckNativeStatus',
                request_serializer=bugs__pb2.CheckNativeStatusReq.SerializeToString,
                response_deserializer=bugs__pb2.CheckNativeStatusRes.FromString,
                )
        self.EvaluateFeatureFlag = channel.unary_unary(
                '/org.couchers.bugs.Bugs/EvaluateFeatureFlag',
                request_serializer=bugs__pb2.EvaluateFeatureFlagReq.SerializeToString,
                response_deserializer=bugs__pb2.EvaluateFeatureFlagRes.FromString,
                )
        self.LogExperimentExposure = channel.unary_unary(
                '/org.couchers.bugs.Bugs/LogExperimentExposure',
                request_serializer=bugs__pb2.LogExperimentExposureReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class BugsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Version(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportBug(self, request, context):
        """Report a bug
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Status(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDescriptors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNativeUpdateManifest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GeolocationSearchInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GeolocationClickInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportDiagnostics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckNativeStatus(self, request, context):
        """Diagnostics ping from the native mobile apps.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EvaluateFeatureFlag(self, request, context):
        """Remotely evaluate a single feature flag for the current session's user (anonymously when
        logged out) and return the resolved value. Evaluated one flag at a time, on demand, so the
        server only evaluates flags the client actually uses - which keeps exposure logging accurate.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LogExperimentExposure(self, request, context):
        """Record a client-side experiment exposure, reported by the SDK as the user is bucketed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BugsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Version': grpc.unary_unary_rpc_method_handler(
                    servicer.Version,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=bugs__pb2.VersionInfo.SerializeToString,
            ),
            'ReportBug': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportBug,
                    request_deserializer=bugs__pb2.ReportBugReq.FromString,
                    response_serializer=bugs__pb2.ReportBugRes.SerializeToString,
            ),
            'Status': grpc.unary_unary_rpc_method_handler(
                    servicer.Status,
                    request_deserializer=bugs__pb2.StatusReq.FromString,
                    response_serializer=bugs__pb2.StatusRes.SerializeToString,
            ),
            'GetDescriptors': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDescriptors,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_api_dot_httpbody__pb2.HttpBody.SerializeToString,
            ),
            'GetNativeUpdateManifest': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNativeUpdateManifest,
                    request_deserializer=google_dot_api_dot_httpbody__pb2.HttpBody.FromString,
                    response_serializer=google_dot_api_dot_httpbody__pb2.HttpBody.SerializeToString,
            ),
            'GeolocationSearchInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GeolocationSearchInfo,
                    request_deserializer=bugs__pb2.GeolocationSearchInfoReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GeolocationClickInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GeolocationClickInfo,
                    request_deserializer=bugs__pb2.GeolocationClickInfoReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ReportDiagnostics': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportDiagnostics,
                    request_deserializer=bugs__pb2.ReportDiagnosticsReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CheckNativeStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckNativeStatus,
                    request_deserializer=bugs__pb2.CheckNativeStatusReq.FromString,
                    response_serializer=bugs__pb2.CheckNativeStatusRes.SerializeToString,
            ),
            'EvaluateFeatureFlag': grpc.unary_unary_rpc_method_handler(
                    servicer.EvaluateFeatureFlag,
                    request_deserializer=bugs__pb2.EvaluateFeatureFlagReq.FromString,
                    response_serializer=bugs__pb2.EvaluateFeatureFlagRes.SerializeToString,
            ),
            'LogExperimentExposure': grpc.unary_unary_rpc_method_handler(
                    servicer.LogExperimentExposure,
                    request_deserializer=bugs__pb2.LogExperimentExposureReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.bugs.Bugs', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Bugs(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Version(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.bugs.Bugs/Version',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            bugs__pb2.VersionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportBug(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.bugs.Bugs/ReportBug',
            bugs__pb2.ReportBugReq.SerializeToString,
            bugs__pb2.ReportBugRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Status(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.bugs.Bugs/Status',
            bugs__pb2.StatusReq.SerializeToString,
            bugs__pb2.StatusRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDescriptors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.bugs.Bugs/GetDescriptors',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_api_dot_httpbody__pb2.HttpBody.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNativeUpdateManifest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.bugs.Bugs/GetNativeUpdateManifest',
            google_dot_api_dot_httpbody__pb2.HttpBody.SerializeToString,
            google_dot_api_dot_httpbody__pb2.HttpBody.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GeolocationSearchInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.bugs.Bugs/GeolocationSearchInfo',
            bugs__pb2.GeolocationSearchInfoReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GeolocationClickInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.bugs.Bugs/GeolocationClickInfo',
            bugs__pb2.GeolocationClickInfoReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportDiagnostics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.bugs.Bugs/ReportDiagnostics',
            bugs__pb2.ReportDiagnosticsReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckNativeStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.bugs.Bugs/CheckNativeStatus',
            bugs__pb2.CheckNativeStatusReq.SerializeToString,
            bugs__pb2.CheckNativeStatusRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EvaluateFeatureFlag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.bugs.Bugs/EvaluateFeatureFlag',
            bugs__pb2.EvaluateFeatureFlagReq.SerializeToString,
            bugs__pb2.EvaluateFeatureFlagRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LogExperimentExposure(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.bugs.Bugs/LogExperimentExposure',
            bugs__pb2.LogExperimentExposureReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import postal_verification_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateCommunityReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PARENT_NODE_ID_FIELD_NUMBER: builtins.int
    ADMIN_IDS_FIELD_NUMBER: builtins.int
    GEOJSON_FIELD_NUMBER: builtins.int
    name: builtins.str
    description: builtins.str
    parent_node_id: builtins.int
    geojson: builtins.str
    @property
    def admin_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        description: builtins.str | None = ...,
        parent_node_id: builtins.int | None = ...,
        admin_ids: collections.abc.Iterable[builtins.int] | None = ...,
        geojson: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["admin_ids", b"admin_ids", "description", b"description", "geojson", b"geojson", "name", b"name", "parent_node_id", b"parent_node_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreateCommunityReq: typing_extensions.TypeAlias = CreateCommunityReq

@typing.final
class UpdateCommunityReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PARENT_NODE_ID_FIELD_NUMBER: builtins.int
    GEOJSON_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    name: builtins.str
    description: builtins.str
    parent_node_id: builtins.int
    geojson: builtins.str
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
        name: builtins.str | None = ...,
        description: builtins.str | None = ...,
        parent_node_id: builtins.int | None = ...,
        geojson: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id", "description", b"description", "geojson", b"geojson", "name", b"name", "parent_node_id", b"parent_node_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateCommunityReq: typing_extensions.TypeAlias = UpdateCommunityReq

@typing.final
class ListEventCommunityInviteRequestsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListEventCommunityInviteRequestsReq: typing_extensions.TypeAlias = ListEventCommunityInviteRequestsReq

@typing.final
class EventCommunityInviteRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_COMMUNITY_INVITE_REQUEST_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    EVENT_URL_FIELD_NUMBER: builtins.int
    APPROX_USERS_TO_NOTIFY_FIELD_NUMBER: builtins.int
    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    event_community_invite_request_id: builtins.int
    user_id: builtins.int
    event_url: builtins.str
    approx_users_to_notify: builtins.int
    """assuming they have notifs enabled"""
    community_id: builtins.int
    def __init__(
        self,
        *,
        event_community_invite_request_id: builtins.int | None = ...,
        user_id: builtins.int | None = ...,
        event_url: builtins.str | None = ...,
        approx_users_to_notify: builtins.int | None = ...,
        community_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["approx_users_to_notify", b"approx_users_to_notify", "community_id", b"community_id", "event_community_invite_request_id", b"event_community_invite_request_id", "event_url", b"event_url", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___EventCommunityInviteRequest: typing_extensions.TypeAlias = EventCommunityInviteRequest

@typing.final
class ListEventCommunityInviteRequestsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUESTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def requests(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___EventCommunityInviteRequest]: ...
    def __init__(
        self,
        *,
        requests: collections.abc.Iterable[Global___EventCommunityInviteRequest] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["next_page_token", b"next_page_token", "requests", b"requests"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListEventCommunityInviteRequestsRes: typing_extensions.TypeAlias = ListEventCommunityInviteRequestsRes

@typing.final
class DecideEventCommunityInviteRequestReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_COMMUNITY_INVITE_REQUEST_ID_FIELD_NUMBER: builtins.int
    APPROVE_FIELD_NUMBER: builtins.int
    event_community_invite_request_id: builtins.int
    approve: builtins.bool
    """whether to approve or deny it"""
    def __init__(
        self,
        *,
        event_community_invite_request_id: builtins.int | None = ...,
        approve: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["approve", b"approve", "event_community_invite_request_id", b"event_community_invite_request_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DecideEventCommunityInviteRequestReq: typing_extensions.TypeAlias = DecideEventCommunityInviteRequestReq

@typing.final
class DecideEventCommunityInviteRequestRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___DecideEventCommunityInviteRequestRes: typing_extensions.TypeAlias = DecideEventCommunityInviteRequestRes

@typing.final
class SendBlogPostNotificationReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BLURB_FIELD_NUMBER: builtins.int
    url: builtins.str
    title: builtins.str
    blurb: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str | None = ...,
        title: builtins.str | None = ...,
        blurb: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["blurb", b"blurb", "title", b"title", "url", b"url"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SendBlogPostNotificationReq: typing_extensions.TypeAlias = SendBlogPostNotificationReq

@typing.final
class MakeUserVolunteerReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    STARTED_VOLUNTEERING_FIELD_NUMBER: builtins.int
    HIDE_ON_TEAM_PAGE_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    role: builtins.str
    started_volunteering: builtins.str
    """date as "yyyy-mm-dd", defaults to today if not provided"""
    hide_on_team_page: builtins.bool
    """defaults to false (i.e., show on team page by default)"""
    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
        role: builtins.str | None = ...,
        started_volunteering: builtins.str | None = ...,
        hide_on_team_page: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["hide_on_team_page", b"hide_on_team_page", "role", b"role", "started_volunteering", b"started_volunteering", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MakeUserVolunteerReq: typing_extensions.TypeAlias = MakeUserVolunteerReq

@typing.final
class UpdateVolunteerReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SORT_KEY_FIELD_NUMBER: builtins.int
    STARTED_VOLUNTEERING_FIELD_NUMBER: builtins.int
    STOPPED_VOLUNTEERING_FIELD_NUMBER: builtins.int
    SHOW_ON_TEAM_PAGE_FIELD_NUMBER: builtins.int
    REINSTATE_VOLUNTEER_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    reinstate_volunteer: builtins.bool
    """if true, clears stopped_volunteering (reinstates a former volunteer as current); cannot be combined with setting stopped_volunteering"""
    @property
    def role(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def sort_key(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def started_volunteering(self) -> google.protobuf.wrappers_pb2.StringValue:
        """dates as "yyyy-mm-dd" """

    @property
    def stopped_volunteering(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def show_on_team_page(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
        role: google.protobuf.wrappers_pb2.StringValue | None = ...,
        sort_key: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        started_volunteering: google.protobuf.wrappers_pb2.StringValue | None = ...,
        stopped_volunteering: google.protobuf.wrappers_pb2.StringValue | None = ...,
        show_on_team_page: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        reinstate_volunteer: builtins.bool | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["role", b"role", "show_on_team_page", b"show_on_team_page", "sort_key", b"sort_key", "started_volunteering", b"started_volunteering", "stopped_volunteering", b"stopped_volunteering"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["reinstate_volunteer", b"reinstate_volunteer", "role", b"role", "show_on_team_page", b"show_on_team_page", "sort_key", b"sort_key", "started_volunteering", b"started_volunteering", "stopped_volunteering", b"stopped_volunteering", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateVolunteerReq: typing_extensions.TypeAlias = UpdateVolunteerReq

@typing.final
class ListVolunteersReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCLUDE_PAST_FIELD_NUMBER: builtins.int
    include_past: builtins.bool
    """if true, include past volunteers (where stopped_volunteering is set)"""
    def __init__(
        self,
        *,
        include_past: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["include_past", b"include_past"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListVolunteersReq: typing_extensions.TypeAlias = ListVolunteersReq

@typing.final
class Volunteer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    IS_BOARD_MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    IMG_FIELD_NUMBER: builtins.int
    SORT_KEY_FIELD_NUMBER: builtins.int
    STARTED_VOLUNTEERING_FIELD_NUMBER: builtins.int
    STOPPED_VOLUNTEERING_FIELD_NUMBER: builtins.int
    SHOW_ON_TEAM_PAGE_FIELD_NUMBER: builtins.int
    LINK_TYPE_FIELD_NUMBER: builtins.int
    LINK_TEXT_FIELD_NUMBER: builtins.int
    LINK_URL_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    name: builtins.str
    """display name"""
    username: builtins.str
    """couchers username"""
    is_board_member: builtins.bool
    """whether the user is a board member (and director)"""
    role: builtins.str
    """volunteer defined role"""
    location: builtins.str
    """location from profile"""
    img: builtins.str
    """avatar from profile"""
    sort_key: builtins.float
    """custom sort order on team page, sorted ascending"""
    started_volunteering: builtins.str
    """dates as "yyyy-mm-dd" """
    stopped_volunteering: builtins.str
    """dates as "yyyy-mm-dd" """
    show_on_team_page: builtins.bool
    link_type: builtins.str
    """link type, one of couchers, email, linkedin, website"""
    link_text: builtins.str
    """the text to be shown on the link"""
    link_url: builtins.str
    """the URL the link should take you to"""
    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
        name: builtins.str | None = ...,
        username: builtins.str | None = ...,
        is_board_member: builtins.bool | None = ...,
        role: builtins.str | None = ...,
        location: builtins.str | None = ...,
        img: builtins.str | None = ...,
        sort_key: builtins.float | None = ...,
        started_volunteering: builtins.str | None = ...,
        stopped_volunteering: builtins.str | None = ...,
        show_on_team_page: builtins.bool | None = ...,
        link_type: builtins.str | None = ...,
        link_text: builtins.str | None = ...,
        link_url: builtins.str | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["_link_text", b"_link_text", "_link_type", b"_link_type", "_link_url", b"_link_url", "_sort_key", b"_sort_key", "_stopped_volunteering", b"_stopped_volunteering", "link_text", b"link_text", "link_type", b"link_type", "link_url", b"link_url", "sort_key", b"sort_key", "stopped_volunteering", b"stopped_volunteering"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["_link_text", b"_link_text", "_link_type", b"_link_type", "_link_url", b"_link_url", "_sort_key", b"_sort_key", "_stopped_volunteering", b"_stopped_volunteering", "img", b"img", "is_board_member", b"is_board_member", "link_text", b"link_text", "link_type", b"link_type", "link_url", b"link_url", "location", b"location", "name", b"name", "role", b"role", "show_on_team_page", b"show_on_team_page", "sort_key", b"sort_key", "started_volunteering", b"started_volunteering", "stopped_volunteering", b"stopped_volunteering", "user_id", b"user_id", "username", b"username"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__link_text: typing_extensions.TypeAlias = typing.Literal["link_text"]
    _WhichOneofArgType__link_text: typing_extensions.TypeAlias = typing.Literal["_link_text", b"_link_text"]
    _WhichOneofReturnType__link_type: typing_extensions.TypeAlias = typing.Literal["link_type"]
    _WhichOneofArgType__link_type: typing_extensions.TypeAlias = typing.Literal["_link_type", b"_link_type"]
    _WhichOneofReturnType__link_url: typing_extensions.TypeAlias = typing.Literal["link_url"]
    _WhichOneofArgType__link_url: typing_extensions.TypeAlias = typing.Literal["_link_url", b"_link_url"]
    _WhichOneofReturnType__sort_key: typing_extensions.TypeAlias = typing.Literal["sort_key"]
    _WhichOneofArgType__sort_key: typing_extensions.TypeAlias = typing.Literal["_sort_key", b"_sort_key"]
    _WhichOneofReturnType__stopped_volunteering: typing_extensions.TypeAlias = typing.Literal["stopped_volunteering"]
    _WhichOneofArgType__stopped_volunteering: typing_extensions.TypeAlias = typing.Literal["_stopped_volunteering", b"_stopped_volunteering"]
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__link_text) -> _WhichOneofReturnType__link_text | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__link_type) -> _WhichOneofReturnType__link_type | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__link_url) -> _WhichOneofReturnType__link_url | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__sort_key) -> _WhichOneofReturnType__sort_key | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__stopped_volunteering) -> _WhichOneofReturnType__stopped_volunteering | None: ...

Global___Volunteer: typing_extensions.TypeAlias = Volunteer

@typing.final
class ListVolunteersRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOLUNTEERS_FIELD_NUMBER: builtins.int
    @property
    def volunteers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Volunteer]: ...
    def __init__(
        self,
        *,
        volunteers: collections.abc.Iterable[Global___Volunteer] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["volunteers", b"volunteers"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListVolunteersRes: typing_extensions.TypeAlias = ListVolunteersRes

@typing.final
class ListPostcardsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListPostcardsReq: typing_extensions.TypeAlias = ListPostcardsReq

@typing.final
class PostcardInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POSTAL_VERIFICATION_ATTEMPT_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    POSTCARD_SENT_AT_FIELD_NUMBER: builtins.int
    VERIFIED_AT_FIELD_NUMBER: builtins.int
    postal_verification_attempt_id: builtins.int
    user_id: builtins.int
    username: builtins.str
    name: builtins.str
    status: postal_verification_pb2.PostalVerificationStatus.ValueType
    @property
    def address(self) -> postal_verification_pb2.PostalAddress: ...
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def postcard_sent_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def verified_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        postal_verification_attempt_id: builtins.int | None = ...,
        user_id: builtins.int | None = ...,
        username: builtins.str | None = ...,
        name: builtins.str | None = ...,
        status: postal_verification_pb2.PostalVerificationStatus.ValueType | None = ...,
        address: postal_verification_pb2.PostalAddress | None = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        postcard_sent_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        verified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["address", b"address", "created", b"created", "postcard_sent_at", b"postcard_sent_at", "verified_at", b"verified_at"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["address", b"address", "created", b"created", "name", b"name", "postal_verification_attempt_id", b"postal_verification_attempt_id", "postcard_sent_at", b"postcard_sent_at", "status", b"status", "user_id", b"user_id", "username", b"username", "verified_at", b"verified_at"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___PostcardInfo: typing_extensions.TypeAlias = PostcardInfo

@typing.final
class ListPostcardsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POSTCARDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def postcards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___PostcardInfo]: ...
    def __init__(
        self,
        *,
        postcards: collections.abc.Iterable[Global___PostcardInfo] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["next_page_token", b"next_page_token", "postcards", b"postcards"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListPostcardsRes: typing_extensions.TypeAlias = ListPostcardsRes

@typing.final
class DownloadPostcardPdfReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POSTAL_VERIFICATION_ATTEMPT_ID_FIELD_NUMBER: builtins.int
    postal_verification_attempt_id: builtins.int
    def __init__(
        self,
        *,
        postal_verification_attempt_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["postal_verification_attempt_id", b"postal_verification_attempt_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DownloadPostcardPdfReq: typing_extensions.TypeAlias = DownloadPostcardPdfReq

@typing.final
class DownloadPostcardPdfRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PDF_FIELD_NUMBER: builtins.int
    pdf: builtins.bytes
    def __init__(
        self,
        *,
        pdf: builtins.bytes | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["pdf", b"pdf"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DownloadPostcardPdfRes: typing_extensions.TypeAlias = DownloadPostcardPdfRes



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetTermsOfServiceRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TERMS_OF_SERVICE_FIELD_NUMBER: builtins.int
    terms_of_service: builtins.str
    """CommonMark without images"""
    def __init__(
        self,
        *,
        terms_of_service: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["terms_of_service", b"terms_of_service"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetTermsOfServiceRes: typing_extensions.TypeAlias = GetTermsOfServiceRes

@typing.final
class CommunityGuideline(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    GUIDELINE_FIELD_NUMBER: builtins.int
    ICON_SVG_FIELD_NUMBER: builtins.int
    title: builtins.str
    guideline: builtins.str
    icon_svg: builtins.str
    def __init__(
        self,
        *,
        title: builtins.str | None = ...,
        guideline: builtins.str | None = ...,
        icon_svg: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["guideline", b"guideline", "icon_svg", b"icon_svg", "title", b"title"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CommunityGuideline: typing_extensions.TypeAlias = CommunityGuideline

@typing.final
class GetCommunityGuidelinesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_GUIDELINES_FIELD_NUMBER: builtins.int
    @property
    def community_guidelines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___CommunityGuideline]: ...
    def __init__(
        self,
        *,
        community_guidelines: collections.abc.Iterable[Global___CommunityGuideline] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_guidelines", b"community_guidelines"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetCommunityGuidelinesRes: typing_extensions.TypeAlias = GetCommunityGuidelinesRes

@typing.final
class Region(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALPHA3_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    alpha3: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        alpha3: builtins.str | None = ...,
        name: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["alpha3", b"alpha3", "name", b"name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Region: typing_extensions.TypeAlias = Region

@typing.final
class GetRegionsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGIONS_FIELD_NUMBER: builtins.int
    @property
    def regions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Region]: ...
    def __init__(
        self,
        *,
        regions: collections.abc.Iterable[Global___Region] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["regions", b"regions"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetRegionsRes: typing_extensions.TypeAlias = GetRegionsRes

@typing.final
class Language(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    code: builtins.str
    """ISO639-3 lowercase language code"""
    name: builtins.str
    def __init__(
        self,
        *,
        code: builtins.str | None = ...,
        name: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["code", b"code", "name", b"name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Language: typing_extensions.TypeAlias = Language

@typing.final
class GetLanguagesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGES_FIELD_NUMBER: builtins.int
    @property
    def languages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Language]: ...
    def __init__(
        self,
        *,
        languages: collections.abc.Iterable[Global___Language] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["languages", b"languages"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetLanguagesRes: typing_extensions.TypeAlias = GetLanguagesRes

@typing.final
class Badge(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    description: builtins.str
    color: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str | None = ...,
        name: builtins.str | None = ...,
        description: builtins.str | None = ...,
        color: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["color", b"color", "description", b"description", "id", b"id", "name", b"name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Badge: typing_extensions.TypeAlias = Badge

@typing.final
class GetBadgesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BADGES_FIELD_NUMBER: builtins.int
    @property
    def badges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Badge]: ...
    def __init__(
        self,
        *,
        badges: collections.abc.Iterable[Global___Badge] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["badges", b"badges"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetBadgesRes: typing_extensions.TypeAlias = GetBadgesRes
